@@ -1,3 +1,5 @@
+
+
 def extract_ids(string):
     if string and string[0] == '[':
         string = string[1:-1]
@@ -29,3 +31,24 @@ def sanitize_id_array(model, obj):
             print([entity[model.id_field_name()] for entity in sanitized_list])
             return [entity[model.id_field_name()] for entity in sanitized_list]
     raise ValueError(f"Invalid type <{repr(obj)}> of argument for sanitize_id_array")
+
+
+def m2m_aggregation_subquery_alias(model, relation_name):
+    return f'{model.table_name}_{relation_name}'
+
+
+#def build_where_clause(model, filter_condition=None, **kwargs):
+#    # todo: this is garbage
+#    if filter_condition is None:
+#        filter_conditions = []
+#        for key, value in kwargs.items():
+#            filter_conditions.append(
+#                Equals.column_as_parameter(ColumnReference(key, table=model.table_name), value))
+#        if filter_conditions:
+#            return WhereClause(filter_conditions[0])
+#        else:
+#            return None
+#    else:
+#        return WhereClause(filter_condition)
+
+
