@@ -104,13 +104,14 @@ class NumericalLiteral(Literal):
     def __init__(self, value):
         if isinstance(value, str):
             if NumericalLiteral.is_int(value):
-                self.value = int(value)
+                v = int(value)
             elif NumericalLiteral.is_float(value):
-                self.value = float(value)
+                v = float(value)
             else:
-                self.value = value
+                v = value
         else:
-            self.value = value
+            v = value
+        super().__init__(v)
 
     @staticmethod
     def is_float(value):
@@ -130,14 +131,20 @@ class NumericalLiteral(Literal):
 
 
 class Predicate:
-    pass
+
+    @property
+    def params(self):
+        return []
+
+    @property
+    def columns(self):
+        return []
 
 
 class BooleanLiteral(Literal, Predicate):
 
     def __init__(self, value):
-        # init of super class
-        self.value = value
+        super().__init__(value)
 
     def __repr__(self):
         if self.value is None:
@@ -168,7 +175,14 @@ class ComparisionOperator(Predicate):
 
     @property
     def columns(self):
-        return self.lhs.columns + self.rhs.columns
+        # todo: refactor this into utility method which takes as parameters an arbitrary number of objects
+        if hasattr(self.lhs, 'columns') and hasattr(self.rhs, 'columns'):
+            return self.lhs.columns + self.rhs.columns
+        if hasattr(self.lhs, 'columns'):
+            return self.lhs.columns
+        if hasattr(self.rhs, 'columns'):
+            return self.rhs.columns
+        return []
 
 
 class Equals(ComparisionOperator):
